@@ -9,38 +9,45 @@ UseMethod("glmnet")
 #' @rdname glmnet
 #' @method glmnet default
 #' @export
-glmnet.default <- function(x, ...)
-glmnet::glmnet(x, ...)
+glmnet.default <- function(x, y, ...)
+{
+    cl <- match.call()
+    cl[[1]] <- quote(glmnet::glmnet)
+    obj <- glmnet::glmnet(x, y, ...)
+    obj$call <- cl
+    obj
+}
 
 
 #' Formula interface for elastic net modelling with glmnet
 #'
 #' @param x For the default method, a matrix of predictor variables.
+#' @param y For the default method, a response vector or matrix (for a multinomial response).
 #' @param formula A model formula; interaction terms are allowed and will be expanded per the usual rules for linear models.
 #' @param data A data frame or matrix containing the variables in the formula.
 #' @param weights An optional vector of case weights to be used in the fitting process. If missing, defaults to an unweighted fit.
-#' @param offset An optional vector of offsets, an \emph{a priori} known component to be included in the linear predictor.
+#' @param offset An optional vector of offsets, an _a priori_ known component to be included in the linear predictor.
 #' @param subset An optional vector specifying the subset of observations to be used to fit the model.
-#' @param na.action A function which indicates what should happen when the data contains missing values. For the \code{predict} method, \code{na.action = na.pass} will predict missing values with \code{NA}; \code{na.omit} or \code{na.exclude} will drop them.
-#' @param drop.unused.levels Should factors have unused levels dropped? Defaults to \code{FALSE}.
+#' @param na.action A function which indicates what should happen when the data contains missing values. For the `predict` method, `na.action = na.pass` will predict missing values with `NA`; `na.omit` or `na.exclude` will drop them.
+#' @param drop.unused.levels Should factors have unused levels dropped? Defaults to `FALSE`.
 #' @param xlev A named list of character vectors giving the full set of levels to be assumed for each factor.
-#' @param alpha The elastic net mixing parameter. See \code{\link[glmnet:glmnet]{glmnet::glmnet}} for more details.
-#' @param sparse Should the model matrix be in sparse format? This can save memory when dealing with many factor variables, each with many levels (but see the warning below).
-#' @param use.model.frame Should the base \code{\link{model.frame}} function be used when constructing the model matrix? This is the standard method that most R modelling functions use, but has some disadvantages. The default is to avoid \code{model.frame} and construct the model matrix term-by-term; see \link[=glmnet.model.matrix]{discussion}.
-#' @param ... For \code{glmnet.formula} and \code{glmnet.default}, other arguments to be passed to \code{\link[glmnet:glmnet]{glmnet::glmnet}}; for the \code{predict} and \code{coef} methods, arguments to be passed to their counterparts in package \code{glmnet}.
+#' @param alpha The elastic net mixing parameter. See [glmnet::glmnet] for more details.
+#' @param sparse Should the model matrix be in sparse format? This can save memory when dealing with many factor variables, each with many levels.
+#' @param use.model.frame Should the base [model.frame] function be used when constructing the model matrix? This is the standard method that most R modelling functions use, but has some disadvantages. The default is to avoid `model.frame` and construct the model matrix term-by-term; see [discussion][glmnet.model.matrix].
+#' @param ... For `glmnet.formula` and `glmnet.default`, other arguments to be passed to [glmnet::glmnet]; for the `predict` and `coef` methods, arguments to be passed to their counterparts in package glmnet.
 #'
 #' @details
-#' The \code{glmnet} function in this package is an S3 generic with a formula and a default method. The former calls the latter, and the latter is simply a direct call to the \code{glmnet} function in package \code{glmnet}. All the arguments to \code{glmnet::glmnet} are (or should be) supported.
+#' The `glmnet` function in this package is an S3 generic with a formula and a default method. The former calls the latter, and the latter is simply a direct call to the `glmnet` function in package glmnet. All the arguments to `glmnet::glmnet` are (or should be) supported.
 #'
-#' The code works in a similar manner to \code{lm}, \code{glm} and other modelling functions. The arguments are used to generate a \emph{model frame}, which is a data frame augmented with information about the roles the columns play in fitting the model. This is then turned into a \emph{model matrix} and a response vector, which are passed to \code{glmnet::glmnet} along with any arguments in \code{...}. If \code{sparse} is TRUE, then \code{Matrix::sparse.model.matrix} is used instead of \code{stats::model.matrix} to create the model matrix.
+#' There are two ways in which the matrix of predictors can be generated. The default, with `use.model.frame = FALSE`, is to process the additive terms in the formula independently. With wide datasets, this is much faster and more memory-efficient than the standard R approach which uses the `model.frame` and `model.matrix` functions. However, the resulting model object is not exactly the same as if the standard approach had been used; in particular, it lacks a bona fide [terms] object. If you require interoperability with other packages that assume the standard model object structure, set `use.model.frame = TRUE`. See [discussion][glmnet.model.matrix] for more information on this topic.
 #'
-#' The \code{predict} and \code{coef} methods are wrappers for the corresponding methods in the \code{glmnet} package. The former constructs a predictor model matrix from its \code{newdata} argument and passes that as the \code{newx} argument to \code{glmnet:::predict.glmnet}.
+#' The `predict` and `coef` methods are wrappers for the corresponding methods in the glmnet package. The former constructs a predictor model matrix from its `newdata` argument and passes that as the `newx` argument to `glmnet:::predict.glmnet`.
 #'
 #' @section Value:
-#' For \code{glmnet.formula}, an object of class \code{glmnet.formula}. This is basically the same object created by \code{glmnet::glmnet}, but with extra components to allow formula usage.
+#' For `glmnet.formula`, an object of class `glmnet.formula`. This is basically the same object created by `glmnet::glmnet`, but with extra components to allow formula usage.
 #'
 #' @seealso
-#' \code{\link[glmnet:glmnet]{glmnet::glmnet}}, \code{\link[glmnet:predict.glmnet]{glmnet:::predict.glmnet}}, \code{\link[glmnet:coef.glmnet]{glmnet:::coef.glmnet}}, \code{\link{model.frame}}, \code{\link{model.matrix}}
+#' [glmnet::glmnet], [glmnet::predict.glmnet], [glmnet::coef.glmnet], [model.frame], [model.matrix]
 #' 
 #' @examples
 #' glmnet(mpg ~ ., data=mtcars)
@@ -84,8 +91,8 @@ glmnet.formula <- function(formula, data, alpha=1, ..., weights=NULL, offset=NUL
 }
 
 
-#' @param object For the \code{predict} and \code{coef} methods, an object of class \code{glmnet.formula}.
-#' @param newdata For the \code{predict} method, a data frame containing the observations for which to calculate predictions.
+#' @param object For the `predict` and `coef` methods, an object of class `glmnet.formula`.
+#' @param newdata For the `predict` method, a data frame containing the observations for which to calculate predictions.
 #' @rdname glmnet
 #' @importFrom Matrix sparse.model.matrix
 #' @export
@@ -104,6 +111,7 @@ predict.glmnet.formula <- function(object, newdata, offset=NULL, na.action=na.pa
     cl[[1]] <- if(object$use.model.frame)
         makeModelComponentsMF
     else makeModelComponents
+
     xy <- eval.parent(cl)
     x <- xy$x
     offset <- xy$offset
@@ -124,8 +132,8 @@ coef.glmnet.formula <- function(object, ...)
 }
 
 
-#' @param digits Significant digits in printed output
-#' @param print.deviance.ratios Whether to print the table of deviance ratios, as per \code{\link[glmnet:print.glmnet]{glmnet:::print.glmnet}}
+#' @param digits Significant digits in printed output.
+#' @param print.deviance.ratios Whether to print the table of deviance ratios, as per [glmnet::print.glmnet].
 #' @rdname glmnet
 #' @export
 #' @method print glmnet.formula
