@@ -46,7 +46,7 @@ test_that("specifying foldid, nfolds works", {
     set.seed(898989)
     mod1 <- cva.glmnet(medv ~ ., data=Boston, nfolds=5)
     set.seed(898989)
-    id <- sample(1:5, nrow(Boston), replace=TRUE)
+    id <- sample(rep(seq_len(5), length=nrow(Boston)))
     mod2 <- cva.glmnet(medv ~ ., data=Boston, nfolds=5, foldid=id)
 
     mod1c <- coef(mod1, alpha=1)
